/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "cmdexec.h"
#include "shellinstance.h"
#include "iosystem.h"
#include <stdlib.h>

#include "debugnew.h"

namespace shellp
{

CmdExecute::CmdExecute(const std::string &cmdName) : ShellCommand(cmdName)
{
	m_pCommandArg = new ShellCmdStringArg("command");
	m_pCommandArg->setDescription("Command string to be executed.");
	addArgument(m_pCommandArg);
	
	setDescription("Executes a command.");
}

CmdExecute::~CmdExecute()
{
	delete m_pCommandArg;
}

bool CmdExecute::execute()
{
	ShellInstance *pInst = ShellInstance::getInstance();
	IOSystem *m_pIOSys = pInst->getIOSystem();

	std::string info = std::string("Executing command: ") + m_pCommandArg->getValue();

	m_pIOSys->writeOutputLine(info);
	
	system(m_pCommandArg->getValue().c_str());

	m_pIOSys->writeOutputLine("Done");
	
	return true;
}

} // end namespace
