/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "cmdexit.h"
#include "shellinstance.h"

#include "debugnew.h"

namespace shellp
{

CmdExit::CmdExit(const std::string &cmdname) : ShellCommand(cmdname)
{
	m_pForce = new ShellCmdBoolArg("force", "no");
	m_pForce->setDescription("In interactive mode, force exit even if it hasn't been saved. In non-interactive mode this flag is ignored.");
	addArgument(m_pForce);

	setDescription("Leaves the application");
}

CmdExit::~CmdExit()
{
	delete m_pForce;
}

bool CmdExit::execute()
{
	ShellInstance *pInst = ShellInstance::getInstance();

	if (pInst->isInteractive())
	{
		bool force = m_pForce->getValue();

		if (force || (!force && pInst->isSaved()))
			pInst->setRequestExit();
		else
		{
			setErrorString("Not saved, specify force flag to override");
			return false;
		}
	}
	else
		pInst->setRequestExit();
	return true;
}

} // end namespace
