/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_NCURSESIOSYSTEM_H

#define SHELLP_NCURSESIOSYSTEM_H

#include "iosystem.h"
#include <stdint.h>
#include <list>

#define NCURSESIOSYSTEM_NUM_KEYVALUES 25

namespace shellp
{

class NCursesIOSystem : public IOSystem
{
public:
	NCursesIOSystem();
	~NCursesIOSystem();
	bool init(bool useCBreakInsteadOfRaw = false);
	void writeOutputLine(const std::string &line, bool newline = true);
private:
	uint32_t GetKey();
	void writeSingleOutputLine(const std::string &line, bool newline);
	bool readInputLineInternal(std::string &line);
	void writeInputPrefix(const std::string &prefix);
	
	static uint32_t valuetable[NCURSESIOSYSTEM_NUM_KEYVALUES][3];
	void *stdscr;
	std::string msg;
	int msglen;
	std::list<std::string> cmdlinehistory;
};

} // end namespace

#endif // SHELLP_NCURSESIOSYSTEM_H

