/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_QTIOSYSTEM_H

#define SHELLP_QTIOSYSTEM_H

#include "shellconfig.h"
#include "iosystem.h"
#include "signalwaiter.h"
#include <jthread/jmutex.h>
#include <string>
#include <list>

namespace shellp
{

class ShellMainWin;

class QtIOSystem : public IOSystem
{
public:
	QtIOSystem(ShellMainWin *pMainWin);
	~QtIOSystem();

	void writeOutputLine(const std::string &line, bool newline = true);
	void setPercentageFeedback(double pct);
	
	bool supports2DPlot() const;
	bool supports3DPlot() const;
	bool plot2D(int id, const std::string &title,
			    const std::string &xLabel, const std::string &yLabel,
			    const std::vector<double> &xPoints, const std::vector<double> &yPoints,
			    bool forceShow);
	bool plot3D(int id, const std::string &title, 
			  const std::string &xLabel, const std::string &yLabel,
			  const std::string &zLabel,
			  double xOff, double yOff, double xDist, double yDist,
			  double xMultiplier, double yMultiplier, double zMultiplier,
			  const std::vector<double> &data, int numX, int numY, bool forceShow);

	void writeStatusLine(const std::string &str);

	void enterInputLine(const std::string &line);
private:
	bool readInputLineInternal(std::string &line);

	SignalWaiter m_waiter;
	jthread::JMutex m_mutex;
	std::list<std::string> m_enteredLines;
	ShellMainWin *m_pMainWin;
};

} // end namespace

#endif // SHELLP_QTIOSYSTEM_H
