/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#include "shellcmdchoicearg.h"

#include "debugnew.h"

namespace shellp
{

ShellCmdChoiceArg::ShellCmdChoiceArg(const std::string &argName) : ShellCmdArg(Choice, argName)
{
	m_val = -1;
}

ShellCmdChoiceArg::ShellCmdChoiceArg(const std::string &argName, const std::string &defaultValue) : ShellCmdArg(Choice, argName, defaultValue)
{
	m_val = -1;
}

ShellCmdChoiceArg::~ShellCmdChoiceArg()
{
}

bool ShellCmdChoiceArg::registerChoice(const std::string &choiceName, const std::string &choiceDescription, int value)
{
	if (value < 0)
	{
		setErrorString("Value should be zero or positive");
		return false;
	}

	for (int i = 0 ; i < m_choices.size() ; i++)
	{
		/*if (m_choices[i].getValue() == value)
		{
			setErrorString("Value is already in use");
			return false;
		}*/
		if (m_choices[i].getName() == choiceName)
		{
			setErrorString("Choice name is already in use");
			return false;
		}
	}

	m_choices.push_back(ChoiceInfo(choiceName, choiceDescription, value));

	return true;
}

bool ShellCmdChoiceArg::parse(const std::string &arg)
{
	int value = -1;

	for (int i = 0 ; value < 0 && i < m_choices.size() ; i++)
	{
		if (arg == m_choices[i].getName())
			value = m_choices[i].getValue();
	}

	if (value < 0)
	{
		setErrorString("Specified argument is not a valid choice");
		return false;
	}

	m_val = value;
	return true;
}

bool ShellCmdChoiceArg::getChoiceInfo(int i, std::string &name, std::string &description, int &value) const
{
	if (i < 0 || i >= m_choices.size())
	{
		setErrorString("Choice index is invalid");
		return false;
	}

	name = m_choices[i].getName();
	description = m_choices[i].getDescription();
	value = m_choices[i].getValue();

	return true;
}

} // end namespace
