/*
    
  This file is a part of Shellp, a 'shell helper' library.
  
  Copyright (C) 2011-2012 Jori Liesenborgs
  
  Contact: jori.liesenborgs@gmail.com

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA

*/

#ifndef SHELLP_SHELLCMDREALARG_H

#define SHELLP_SHELLCMDREALARG_H

#include "shellconfig.h"
#include "shellcmdarg.h"

namespace shellp
{

class SHELLP_IMPORTEXPORT ShellCmdRealArg : public ShellCmdArg
{
public:
	ShellCmdRealArg(const std::string &name, int unitID = -1);
	ShellCmdRealArg(const std::string &name, const std::string &defaultValue, int unitID = -1);
	~ShellCmdRealArg();

	void setUnitType(int unitID)							{ m_unitID = unitID; }

	void setMin(double val)								{ m_minval = val; m_usemin = true; }
	void setMax(double val)								{ m_maxval = val; m_usemax = true; }
	void clearMin()									{ m_usemin = false; }
	void clearMax()									{ m_usemax = false; }
	bool useMin() const								{ return m_usemin; }
	bool useMax() const								{ return m_usemax; }
	double getMin() const								{ return m_minval; }
	double getMax() const								{ return m_maxval; }
	bool parse(const std::string &arg);
	double getValue() const								{ return m_val; }

	bool hasUnitMultiplier() const							{ if (m_unitID < 0) return false; return true; }
	std::string getUnitName() const;
private:
	bool m_usemin, m_usemax;
	double m_minval, m_maxval;
	double m_val;
	int m_unitID;
};

} // end namespace

#endif // SHELLP_SHELLCMDREALARG_H
